***STATE HIRING CREDITS***
*Neumark - Grijalva 2016
*Forthcoming ILRR
*Table 6 and Figure 3 graphs

clear
set more off
set matsize 2000

global data "C:\Users\Diego\Documents\Documents\USFQ\Publications\JCHC\Replication\data\Monthly"

cd $data
use JCHCdatabase_monthly, clear

*Merge cyclical indicator
merge 1:1 sname year month using pse06final
drop _merge
merge 1:1 sname year month using pse90final
drop _merge

*Merge political variables
merge 1:1 sname year month using political_variables
drop _merge
 
*Merge Unemployment Insurance Data
merge 1:1 state year month using uiweekcontrols
drop _merge

*Merge housing data
merge 1:1 sname year month using housing_data
drop _merge

*Merge ARRA data
merge 1:1 state year month using ARRA.dta
drop _merge

*Drop the District of Columbia
drop if state==11

*Save results in a Matrix for easy saving
*The first row is the coefficient
*The second row is the standard error
matrix input linco = (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0)
gen k=1

*Same but for ARRA tests
*The first row is the coefficient
*The second row is the p-value
matrix input arra = (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0)
gen m=1

*Same but for multiple tests
*The first row is the coefficient
*The second row is the p-value
matrix input mult = (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0)
gen i=1

*Same but for joint significance tests
*The first row is the coefficient
*The second row is the p-value
matrix input joint = (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0)
gen j=1

sort state year month

rename q1 qn1
rename q2 qn2
rename q3 qn3
rename q4 qn4
rename q5 qn5

*Taking logs of toba tobnoDOL tpda tpdnoDOL
gen ltobnoDOL = log(tobnoDOL)

*Convert credit counts to dummies for 1 = at least one credit, 0 = none
*Generate lags of these variables
foreach var of varlist jc aet acf ar ans recp nrecp teu tew ted nte {
   quietly replace `var' = 1 if `var'>1 & `var'~=.
   quietly gen `var'1 = `var'[_n-1] if state[_n] == state[_n-1]
   quietly gen `var'2 = `var'[_n-2] if state[_n] == state[_n-2]
   quietly gen `var'3 = `var'[_n-3] if state[_n] == state[_n-3]
   quietly gen `var'4 = `var'[_n-4] if state[_n] == state[_n-4]
   quietly gen `var'5 = `var'[_n-5] if state[_n] == state[_n-5]
   quietly gen `var'6 = `var'[_n-6] if state[_n] == state[_n-6]
   quietly gen `var'7 = `var'[_n-7] if state[_n] == state[_n-7]
   quietly gen `var'8 = `var'[_n-8] if state[_n] == state[_n-8]
   quietly gen `var'9 = `var'[_n-9] if state[_n] == state[_n-9]
   quietly gen `var'10 = `var'[_n-10] if state[_n] == state[_n-10]
   quietly gen `var'11 = `var'[_n-11] if state[_n] == state[_n-11]
   quietly gen `var'12 = `var'[_n-12] if state[_n] == state[_n-12]
   quietly gen `var'13 = `var'[_n-13] if state[_n] == state[_n-13]
   
   *First Differences
   quietly gen d`var' = `var' - `var'1
   quietly gen d`var'1 = `var'1 - `var'2
   quietly gen d`var'2 = `var'2 - `var'3
   quietly gen d`var'3 = `var'3 - `var'4
   quietly gen d`var'4 = `var'4 - `var'5
   quietly gen d`var'5 = `var'5 - `var'6
   quietly gen d`var'6 = `var'6 - `var'7
   quietly gen d`var'7 = `var'7 - `var'8
   quietly gen d`var'8 = `var'8 - `var'9
   quietly gen d`var'9 = `var'9 - `var'10
   quietly gen d`var'10 = `var'10 - `var'11
   quietly gen d`var'11 = `var'11 - `var'12
   quietly gen d`var'12 = `var'12 - `var'13
}

*Same thing but for lpse, lminwage, and weeks_euc
foreach var of varlist lminwage weeks_euc lpse4naics06 {
   quietly gen `var'1 = `var'[_n-1] if state[_n] == state[_n-1]
   quietly gen `var'2 = `var'[_n-2] if state[_n] == state[_n-2]
   quietly gen `var'3 = `var'[_n-3] if state[_n] == state[_n-3]
   quietly gen `var'4 = `var'[_n-4] if state[_n] == state[_n-4]
   quietly gen `var'5 = `var'[_n-5] if state[_n] == state[_n-5]
   quietly gen `var'6 = `var'[_n-6] if state[_n] == state[_n-6]
   quietly gen `var'7 = `var'[_n-7] if state[_n] == state[_n-7]
   quietly gen `var'8 = `var'[_n-8] if state[_n] == state[_n-8]
   quietly gen `var'9 = `var'[_n-9] if state[_n] == state[_n-9]
   quietly gen `var'10 = `var'[_n-10] if state[_n] == state[_n-10]
   quietly gen `var'11 = `var'[_n-11] if state[_n] == state[_n-11]
   quietly gen `var'12 = `var'[_n-12] if state[_n] == state[_n-12]
   quietly gen `var'13 = `var'[_n-13] if state[_n] == state[_n-13]
   
   *First Differences
   quietly gen d`var' = `var' - `var'1
   quietly gen d`var'1 = `var'1 - `var'2
   quietly gen d`var'2 = `var'2 - `var'3
   quietly gen d`var'3 = `var'3 - `var'4
   quietly gen d`var'4 = `var'4 - `var'5
   quietly gen d`var'5 = `var'5 - `var'6
   quietly gen d`var'6 = `var'6 - `var'7
   quietly gen d`var'7 = `var'7 - `var'8
   quietly gen d`var'8 = `var'8 - `var'9
   quietly gen d`var'9 = `var'9 - `var'10
   quietly gen d`var'10 = `var'10 - `var'11
   quietly gen d`var'11 = `var'11 - `var'12
   quietly gen d`var'12 = `var'12 - `var'13
}

*Generate lags of the political variables
*Generate first differences of these variables
foreach var of varlist govparty_c  {
quietly gen `var'1 = `var'[_n-1] if state[_n] == state[_n-1]

quietly gen d`var' = `var' - `var'1
}


*First Difference of log employment
gen dll = ll[_n] - ll[_n-1] if state[_n]==state[_n-1]

*Generate lags of ARRA variables
foreach var of varlist ltobnoDOL {
   quietly gen `var'1 = `var'[_n-1] if state[_n] == state[_n-1]
   quietly gen `var'2 = `var'[_n-2] if state[_n] == state[_n-2]
   quietly gen `var'3 = `var'[_n-3] if state[_n] == state[_n-3]
   quietly gen `var'4 = `var'[_n-4] if state[_n] == state[_n-4]
   quietly gen `var'5 = `var'[_n-5] if state[_n] == state[_n-5]
   quietly gen `var'6 = `var'[_n-6] if state[_n] == state[_n-6]
   quietly gen `var'7 = `var'[_n-7] if state[_n] == state[_n-7]
   quietly gen `var'8 = `var'[_n-8] if state[_n] == state[_n-8]
   quietly gen `var'9 = `var'[_n-9] if state[_n] == state[_n-9]
   quietly gen `var'10 = `var'[_n-10] if state[_n] == state[_n-10]
   quietly gen `var'11 = `var'[_n-11] if state[_n] == state[_n-11]
   quietly gen `var'12 = `var'[_n-12] if state[_n] == state[_n-12]
   quietly gen `var'13 = `var'[_n-13] if state[_n] == state[_n-13]
   quietly gen `var'14 = `var'[_n-14] if state[_n] == state[_n-14]
   quietly gen `var'15 = `var'[_n-15] if state[_n] == state[_n-15]
   quietly gen `var'16 = `var'[_n-16] if state[_n] == state[_n-16]
   quietly gen `var'17 = `var'[_n-17] if state[_n] == state[_n-17]
   quietly gen `var'18 = `var'[_n-18] if state[_n] == state[_n-18]
   quietly gen `var'19 = `var'[_n-19] if state[_n] == state[_n-19]
   quietly gen `var'20 = `var'[_n-20] if state[_n] == state[_n-20]
   quietly gen `var'21 = `var'[_n-21] if state[_n] == state[_n-21]
   quietly gen `var'22 = `var'[_n-22] if state[_n] == state[_n-22]
   quietly gen `var'23 = `var'[_n-23] if state[_n] == state[_n-23]
   quietly gen `var'24 = `var'[_n-24] if state[_n] == state[_n-24]
   quietly gen `var'25 = `var'[_n-25] if state[_n] == state[_n-25]

   *First Differences
   quietly gen d`var' = `var' - `var'1
   quietly gen d`var'1 = `var'1 - `var'2
   quietly gen d`var'2 = `var'2 - `var'3
   quietly gen d`var'3 = `var'3 - `var'4
   quietly gen d`var'4 = `var'4 - `var'5
   quietly gen d`var'5 = `var'5 - `var'6
   quietly gen d`var'6 = `var'6 - `var'7
   quietly gen d`var'7 = `var'7 - `var'8
   quietly gen d`var'8 = `var'8 - `var'9
   quietly gen d`var'9 = `var'9 - `var'10
   quietly gen d`var'10 = `var'10 - `var'11
   quietly gen d`var'11 = `var'11 - `var'12
   quietly gen d`var'12 = `var'12 - `var'13
   quietly gen d`var'13 = `var'13 - `var'14
   quietly gen d`var'14 = `var'14 - `var'15
   quietly gen d`var'15 = `var'15 - `var'16
   quietly gen d`var'16 = `var'16 - `var'17
   quietly gen d`var'17 = `var'17 - `var'18
   quietly gen d`var'18 = `var'18 - `var'19
   quietly gen d`var'19 = `var'19 - `var'20
   quietly gen d`var'20 = `var'20 - `var'21
   quietly gen d`var'21 = `var'21 - `var'22
   quietly gen d`var'22 = `var'22 - `var'23
   quietly gen d`var'23 = `var'23 - `var'24
   quietly gen d`var'24 = `var'24 - `var'25
}


*Select the proper years of data for the sample
drop if year <= 2006 | year == 2012

*INTERACIONS

*State dummies
sort state year month
egen statedum = group(state)
quietly tab statedum, generate (sdum)
drop statedum

*Month dummies
egen timedum = group(year month)
sort timedum
quietly tab timedum, generate(mdum)
drop timedum

*Calendar month dummies
egen monthlydum = group(month)
quietly tab monthlydum, generate(monthdum)
drop monthlydum

*Interactions
foreach var1 of varlist sdum* {
foreach var2 of varlist monthdum* {
gen int`var1'`var2' = `var1' *`var2'
}
}

foreach var of varlist sdum* {
gen int`var'lpse4naics06 = `var'*lpse4naics06
}

*Interactions of housing variables
foreach var1 of varlist qn*{
foreach var2 of varlist mdum* {
gen int`var1'`var2' = `var1'*`var2'
}
}

sort state year month

*First differences of interactions
foreach var of varlist mdum* intsdum*monthdum* intsdum*lpse4naics06 {
quietly gen d`var' = `var'[_n] - `var'[_n-1] if state[_n] == state[_n-1]
}


*Program for linear tests
capture program drop linearcombos
program define linearcombos

lincom `1'
matrix linco[1,k] = r(estimate)
matrix linco[2,k] = r(se)
replace k=k+1

lincom `1' + `1'1 + `1'2 + `1'3 + `1'4
matrix linco[1,k] = r(estimate)
matrix linco[2,k] = r(se)
replace k=k+1

lincom `1' + `1'1 + `1'2 + `1'3 +`1'4 + `1'5 + `1'6 + `1'7 + `1'8
matrix linco[1,k] = r(estimate)
matrix linco[2,k] = r(se)
replace k=k+1

lincom `1' + `1'1 + `1'2 + `1'3 + `1'4 + `1'5 + `1'6 + `1'7 +`1'8 + `1'9 + `1'10 + `1'11 + `1'12
matrix linco[1,k] = r(estimate)
matrix linco[2,k] = r(se)
replace k=k+1

end

*Program for linear tests on ARRA
capture program drop linearcombo
program define linearcombo

lincom `1'
matrix arra[1,m] = r(estimate)
matrix arra[2,m] = r(se)
replace m=m+1

lincom `1' + `1'1 + `1'2 + `1'3 + `1'4 + `1'5 + `1'6
matrix arra[1,m] = r(estimate)
matrix arra[2,m] = r(se)
replace m=m+1

lincom `1' + `1'1 + `1'2 + `1'3 + `1'4 + `1'5 + `1'6 + `1'7 + `1'8 + `1'9 + `1'10 + `1'11 + `1'12 
matrix arra[1,m] = r(estimate)
matrix arra[2,m] = r(se)
replace m=m+1

lincom `1' + `1'1 + `1'2 + `1'3 + `1'4 + `1'5 + `1'6 + `1'7 + `1'8 + `1'9 + `1'10 + `1'11 + `1'12 + `1'13 + `1'14 + `1'15 + `1'16 + `1'17 + `1'18 + `1'19 + `1'20 + `1'21 + `1'22 + `1'23 + `1'24
matrix arra[1,m] = r(estimate)
matrix arra[2,m] = r(se)
replace m=m+1

end

*Program for multiple tests
capture program drop multiple
program define multiple
 
lincom `1'
matrix mult[1,i] = r(estimate)
matrix mult[2,i] = 2*ttail(r(df),abs(r(estimate)/r(se)))
replace i=i+1
 
lincom `1' + `1'1 + `1'2 + `1'3 + `1'4
matrix mult[1,i] = r(estimate)
matrix mult[2,i] = 2*ttail(r(df),abs(r(estimate)/r(se)))
replace i=i+1
 
lincom `1' + `1'1 + `1'2 + `1'3 +`1'4 + `1'5 + `1'6 + `1'7 + `1'8
matrix mult[1,i] = r(estimate)
matrix mult[2,i] = 2*ttail(r(df),abs(r(estimate)/r(se)))
replace i=i+1
 
lincom `1' + `1'1 + `1'2 + `1'3 + `1'4 + `1'5 + `1'6 + `1'7 +`1'8 + `1'9 + `1'10 + `1'11 + `1'12
matrix mult[1,i] = r(estimate)
matrix mult[2,i] = 2*ttail(r(df),abs(r(estimate)/r(se)))
replace i=i+1

end

*Program for joint tests
capture program drop jointtests
program define jointtests

test `1' `1'1 `1'2 `1'3 `1'4 `1'5 `1'6 `1'7 `1'8 `1'9 `1'10 `1'11 `1'12
matrix joint[1,j] = r(F)
matrix joint[2,j] = r(p)
replace j=j+1

end

*Program for graphing confidence intervals
capture program drop confidence
program define confidence

est restore `1'
lincomest `1'
est store c`1'

est restore `1'
lincomest `1' + `1'1 
est store c`1'1

est restore `1'
lincomest `1' + `1'1 + `1'2
est store c`1'2

est restore `1'
lincomest `1' + `1'1 + `1'2 + `1'3
est store c`1'3

est restore `1'
lincomest `1' + `1'1 + `1'2 + `1'3 + `1'4
est store c`1'4

est restore `1'
lincomest `1' + `1'1 + `1'2 + `1'3 +`1'4 + `1'5
est store c`1'5

est restore `1'
lincomest `1' + `1'1 + `1'2 + `1'3 +`1'4 + `1'5 + `1'6
est store c`1'6

est restore `1'
lincomest `1' + `1'1 + `1'2 + `1'3 +`1'4 + `1'5 + `1'6 + `1'7
est store c`1'7

est restore `1'
lincomest `1' + `1'1 + `1'2 + `1'3 +`1'4 + `1'5 + `1'6 + `1'7 + `1'8
est store c`1'8

est restore `1'
lincomest `1' + `1'1 + `1'2 + `1'3 + `1'4 + `1'5 + `1'6 + `1'7 +`1'8 + `1'9
est store c`1'9

est restore `1'
lincomest `1' + `1'1 + `1'2 + `1'3 + `1'4 + `1'5 + `1'6 + `1'7 +`1'8 + `1'9 + `1'10
est store c`1'10

est restore `1'
lincomest `1' + `1'1 + `1'2 + `1'3 + `1'4 + `1'5 + `1'6 + `1'7 +`1'8 + `1'9 + `1'10 + `1'11
est store c`1'11

est restore `1'
lincomest `1' + `1'1 + `1'2 + `1'3 + `1'4 + `1'5 + `1'6 + `1'7 +`1'8 + `1'9 + `1'10 + `1'11 + `1'12
est store c`1'12

coefplot (c`1', pstyle(p1) rename((1)=0) offset(0)) (c`1'1, pstyle(p1) rename((1)=1) offset(0)) (c`1'2, pstyle(p1) rename((1)=2) offset(0)) (c`1'3, pstyle(p1) rename((1)=3) offset(0)) (c`1'4, pstyle(p1) rename((1)=4) offset(0)) (c`1'5, pstyle(p1) rename((1)=5) offset(0)) (c`1'6, pstyle(p1) rename((1)=6) offset(0)) (c`1'7, pstyle(p1) rename((1)=7) offset(0)) (c`1'8, pstyle(p1) rename((1)=8) offset(0)) (c`1'9, pstyle(p1) rename((1)=9) offset(0)) (c`1'10, pstyle(p1) rename((1)=10) offset(0)) (c`1'11, pstyle(p1) rename((1)=11) offset(0)) (c`1'12, pstyle(p1) rename((1)=12) offset(0)), vert yline(0) msymbol(o) legend(order(1 "95% CI" 2 "90% CI") row(1)) ciopts(recast(rcap) lwidth(*.5 *1.5)) levels(95 90) weight(1/@se) saving(`1'07-11, replace) yscale(r(-1,2)) ylabel(-1(.5)2)

end

***REGRESSIONS***

drop dintsdum1lpse4naics mdum1 mdum2 intsdum1monthdum*

drop intqn1mdum*
         
forvalues i=2(1)5{
forvalues j=1(1)12 {
drop intqn`i'mdum`j'
}
}

drop intqn2mdum13 intqn3mdum13 intqn4mdum13 intqn5mdum13

global int dlpse4naics06* dlminwage* dweeks_euc* intsdum*monthdum* mdum* dintsdum*lpse4naics06 dltobnoDOL* intqn*

global pol govparty_c

*Credit
reg dll djc* $int $pol, vce(cluster state)
est store djc
matrix coeff = e(b)
matrix covar = e(V)

est restore djc
linearcombos djc
multiple djc
jointtests djc
linearcombo dltobnoDOL

*Amount of credit
reg dll daet* dacf* dar* dans* $int $pol, vce(cluster state)
est store daet
est store dacf
est store dar
est store dans
matrix coeff = e(b)
matrix covar = e(V)

est restore daet
linearcombos daet
multiple daet
jointtests daet
est restore dacf
linearcombos dacf
multiple dacf
jointtests dacf
est restore dar
linearcombos dar
multiple dar
jointtests dar
confidence dar
est restore dans
linearcombos dans
multiple dans
jointtests dans

*Recapture provisions
reg dll drecp* dnrecp* $int $pol, vce(cluster state)
est store drecp
est store dnrecp
matrix coeff = e(b)
matrix covar = e(V)

est restore drecp
linearcombos drecp
multiple drecp
jointtests drecp
confidence drecp
est restore dnrecp
linearcombos dnrecp
multiple dnrecp
jointtests dnrecp

*Target by employee
reg dll dteu* dted* dnte* $int $pol, vce(cluster state)
est store dteu
est store dted
est store dnte
matrix coeff = e(b)
matrix covar = e(V)

est restore dteu
linearcombos dteu
multiple dteu
jointtests dteu
confidence dteu
est restore dted
linearcombos dted
multiple dted
jointtests dted
est restore dnte
linearcombos dnte
multiple dnte
jointtests dnte

***RESULTS***

matrix list linco
matrix lincot=linco'
matrix list mult
matrix multt=mult'
matrix list joint
matrix jointt=joint'
matrix list arra
matrix arrat=arra'

putexcel set Table6, sheet(Results) modify
putexcel B2 = matrix(lincot)

putexcel set Table6, sheet(Multipletests) modify
putexcel B2 = matrix(multt)

putexcel set Table6, sheet(Jointtests) modify
putexcel B2 = matrix(jointt)

putexcel set Table6, sheet(Arra) modify
putexcel B2 = matrix(arrat)

***MULTIPLE TESTING***

clear

*Multiple tests for all estimated variables

import excel Table6.xlsx, sheet(Multipletests) firstrow
drop if p==0

multproc, method(simes) pv(p) puncor(.05) reject(reject05simes) critical(critical05simes)
multproc, method(simes) pv(p) puncor(.1) reject(reject10simes) critical(critical10simes)
multproc, method(sidak) pv(p) puncor(.05) reject(reject05sidak) critical(critical05sidak)
multproc, method(sidak) pv(p) puncor(.1) reject(reject10sidak) critical(critical10sidak)

save multipletests_table6.dta, replace

clear

*Multiple tests for joint effects

import excel Table6.xlsx, sheet(Jointtests) firstrow
drop if p==0

multproc, method(simes) pv(p) puncor(.05) reject(reject05simes) critical(critical05simes)
multproc, method(simes) pv(p) puncor(.1) reject(reject10simes) critical(critical10simes)
multproc, method(sidak) pv(p) puncor(.05) reject(reject05sidak) critical(critical05sidak)
multproc, method(sidak) pv(p) puncor(.1) reject(reject10sidak) critical(critical10sidak)

save jointtests_table6.dta, replace
