***STATE HIRING CREDITS***
*Neumark - Grijalva 2016
*Forthcoming ILRR
*Table 7

clear
set more off
set matsize 10000

global data "C:\Users\Diego\Documents\Documents\USFQ\Publications\JCHC\Replication\data\Monthly"

cd $data
use JCHCdatabase_monthly, clear

*Merge cyclical indicator
merge 1:1 sname year month using pse90final
drop _merge

*Merge political variables
merge 1:1 sname year month using political_variables
drop _merge
 
*Merge Unemployment Insurance Data
merge 1:1 state year month using uiweekcontrols
drop _merge

*Merge recession data
merge 1:1 sname year month using recessions.dta
drop _merge

*Drop the District of Columbia
drop if state==11

*Save results in a Matrix for easy saving
*The first row is the coefficient
*The second row is the standard error
matrix input linco = (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0)
gen k=1

*Same but for joint significance tests
*The first row is the coefficient
*The second row is the p-value
matrix input joint = (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0)
gen j=1

sort state year month

*Convert credit counts to dummies for 1 = at least one credit, 0 = none
*Generate lags of these variables
foreach var of varlist jc aet acf ar ans recp nrecp  {
   quietly replace `var' = 1 if `var'>1 & `var'~=.
   quietly gen `var'1 = `var'[_n-1] if state[_n] == state[_n-1]
   quietly gen `var'2 = `var'[_n-2] if state[_n] == state[_n-2]
   quietly gen `var'3 = `var'[_n-3] if state[_n] == state[_n-3]
   quietly gen `var'4 = `var'[_n-4] if state[_n] == state[_n-4]
   quietly gen `var'5 = `var'[_n-5] if state[_n] == state[_n-5]
   quietly gen `var'6 = `var'[_n-6] if state[_n] == state[_n-6]
   quietly gen `var'7 = `var'[_n-7] if state[_n] == state[_n-7]
   quietly gen `var'8 = `var'[_n-8] if state[_n] == state[_n-8]
   quietly gen `var'9 = `var'[_n-9] if state[_n] == state[_n-9]
   quietly gen `var'10 = `var'[_n-10] if state[_n] == state[_n-10]
   quietly gen `var'11 = `var'[_n-11] if state[_n] == state[_n-11]
   quietly gen `var'12 = `var'[_n-12] if state[_n] == state[_n-12]
   quietly gen `var'13 = `var'[_n-13] if state[_n] == state[_n-13]
   
   *First Differences
   quietly gen d`var' = `var' - `var'1
   quietly gen d`var'1 = `var'1 - `var'2
   quietly gen d`var'2 = `var'2 - `var'3
   quietly gen d`var'3 = `var'3 - `var'4
   quietly gen d`var'4 = `var'4 - `var'5
   quietly gen d`var'5 = `var'5 - `var'6
   quietly gen d`var'6 = `var'6 - `var'7
   quietly gen d`var'7 = `var'7 - `var'8
   quietly gen d`var'8 = `var'8 - `var'9
   quietly gen d`var'9 = `var'9 - `var'10
   quietly gen d`var'10 = `var'10 - `var'11
   quietly gen d`var'11 = `var'11 - `var'12
   quietly gen d`var'12 = `var'12 - `var'13
}

*Same thing but for lpse, lminwage, and weeks_euc
foreach var of varlist lminwage weeks_euc lpse4naics {
   quietly gen `var'1 = `var'[_n-1] if state[_n] == state[_n-1]
   quietly gen `var'2 = `var'[_n-2] if state[_n] == state[_n-2]
   quietly gen `var'3 = `var'[_n-3] if state[_n] == state[_n-3]
   quietly gen `var'4 = `var'[_n-4] if state[_n] == state[_n-4]
   quietly gen `var'5 = `var'[_n-5] if state[_n] == state[_n-5]
   quietly gen `var'6 = `var'[_n-6] if state[_n] == state[_n-6]
   quietly gen `var'7 = `var'[_n-7] if state[_n] == state[_n-7]
   quietly gen `var'8 = `var'[_n-8] if state[_n] == state[_n-8]
   quietly gen `var'9 = `var'[_n-9] if state[_n] == state[_n-9]
   quietly gen `var'10 = `var'[_n-10] if state[_n] == state[_n-10]
   quietly gen `var'11 = `var'[_n-11] if state[_n] == state[_n-11]
   quietly gen `var'12 = `var'[_n-12] if state[_n] == state[_n-12]
   quietly gen `var'13 = `var'[_n-13] if state[_n] == state[_n-13]
   
   *First Differences
   quietly gen d`var' = `var' - `var'1
   quietly gen d`var'1 = `var'1 - `var'2
   quietly gen d`var'2 = `var'2 - `var'3
   quietly gen d`var'3 = `var'3 - `var'4
   quietly gen d`var'4 = `var'4 - `var'5
   quietly gen d`var'5 = `var'5 - `var'6
   quietly gen d`var'6 = `var'6 - `var'7
   quietly gen d`var'7 = `var'7 - `var'8
   quietly gen d`var'8 = `var'8 - `var'9
   quietly gen d`var'9 = `var'9 - `var'10
   quietly gen d`var'10 = `var'10 - `var'11
   quietly gen d`var'11 = `var'11 - `var'12
   quietly gen d`var'12 = `var'12 - `var'13
}


*Generate lags of the political variables
*Generate first differences of these variables
foreach var of varlist govparty_c  {
quietly gen `var'1 = `var'[_n-1] if state[_n] == state[_n-1]

quietly gen d`var' = `var' - `var'1
}

*First Difference of log employment
gen dll = ll[_n] - ll[_n-1] if state[_n]==state[_n-1]

*Generate interactions with recession dummies
*Generate lags of the recession variable
foreach var of varlist recession {
   quietly gen `var'1 = `var'[_n-1] if state[_n] == state[_n-1]
   quietly gen `var'2 = `var'[_n-2] if state[_n] == state[_n-2]
   quietly gen `var'3 = `var'[_n-3] if state[_n] == state[_n-3]
   quietly gen `var'4 = `var'[_n-4] if state[_n] == state[_n-4]
   quietly gen `var'5 = `var'[_n-5] if state[_n] == state[_n-5]
   quietly gen `var'6 = `var'[_n-6] if state[_n] == state[_n-6]
   quietly gen `var'7 = `var'[_n-7] if state[_n] == state[_n-7]
   quietly gen `var'8 = `var'[_n-8] if state[_n] == state[_n-8]
   quietly gen `var'9 = `var'[_n-9] if state[_n] == state[_n-9]
   quietly gen `var'10 = `var'[_n-10] if state[_n] == state[_n-10]
   quietly gen `var'11 = `var'[_n-11] if state[_n] == state[_n-11]
   quietly gen `var'12 = `var'[_n-12] if state[_n] == state[_n-12]
}

	*Generate interactions
foreach var of varlist djc daet dacf dar dans drecp dnrecp {
quietly gen rec`var' = `var'*recession
}

forvalues i=1(1)12 {
foreach var of varlist djc`i' daet`i' dacf`i' dar`i' dans`i' drecp`i' dnrecp`i' {
quietly gen rec`var' = `var'*recession`i'
}
}

*Select the proper years of data for the sample
drop if year<=1990 | year==2012

* INTERACIONS

*State dummies
sort state year month
egen statedum = group(state)
quietly tab statedum, generate (sdum)
drop statedum

*Month dummies
egen timedum = group(year month)
sort timedum
quietly tab timedum, generate(mdum)
drop timedum

*Calendar month dummies
egen monthlydum = group(month)
quietly tab monthlydum, generate(monthdum)
drop monthlydum

*Interactions
foreach var1 of varlist sdum* {
foreach var2 of varlist monthdum* {
gen int`var1'`var2' = `var1'*`var2'
}
}

foreach var of varlist sdum* {
gen int`var'lpse4naics = `var'*lpse4naics
}

sort state year month

*First differences of interactions
foreach var of varlist mdum* intsdum*monthdum* intsdum*lpse4naics {
quietly gen d`var' = `var'[_n] - `var'[_n-1] if state[_n] == state[_n-1]
}

*Program for linear tests
capture program drop linearcombos
program define linearcombos

lincom `1'
matrix linco[1,k] = r(estimate)
matrix linco[2,k] = r(se)
replace k=k+1

lincom `1' + `1'1 + `1'2 + `1'3 + `1'4
matrix linco[1,k] = r(estimate)
matrix linco[2,k] = r(se)
replace k=k+1

lincom `1' + `1'1 + `1'2 + `1'3 + `1'4 + `1'5 + `1'6 + `1'7 + `1'8
matrix linco[1,k] = r(estimate)
matrix linco[2,k] = r(se)
replace k=k+1

lincom `1' + `1'1 + `1'2 + `1'3 + `1'4 + `1'5 + `1'6 + `1'7 + `1'8 + `1'9 + `1'10 + `1'11 + `1'12
matrix linco[1,k] = r(estimate)
matrix linco[2,k] = r(se)
replace k=k+1

end

*Program for linear tests of interactions
capture program drop intcombos
program define intcombos

lincom `1' + `2'
matrix linco[1,k] = r(estimate)
matrix linco[2,k] = r(se)
replace k=k+1

lincom `1' + `1'1 + `1'2 + `1'3 + `1'4 + `2' + `2'1 + `2'2 + `2'3 + `2'4
matrix linco[1,k] = r(estimate)
matrix linco[2,k] = r(se)
replace k=k+1

lincom `1' + `1'1 + `1'2 + `1'3 + `1'4 + `1'5 + `1'6 + `1'7 + `1'8 + `2' + `2'1 + `2'2 + `2'3 + `2'4 + `2'5 + `2'6 + `2'7 + `2'8
matrix linco[1,k] = r(estimate)
matrix linco[2,k] = r(se)
replace k=k+1

lincom `1' + `1'1 + `1'2 + `1'3 + `1'4 + `1'5 + `1'6 + `1'7 + `1'8 + `1'9 + `1'10 + `1'11 + `1'12 + `2' + `2'1 + `2'2 + `2'3 + `2'4 + `2'5 + `2'6 + `2'7 + `2'8 + `2'9 + `2'10 + `2'11 + `2'12
matrix linco[1,k] = r(estimate)
matrix linco[2,k] = r(se)
replace k=k+1

end

*Program for joint tests
capture program drop jointtests
program define jointtests

test `1' `1'1 `1'2 `1'3 `1'4 `1'5 `1'6 `1'7 `1'8 `1'9 `1'10 `1'11 `1'12
matrix joint[1,j] = r(F)
matrix joint[2,j] = r(p)
replace j=j+1

end

*Program for interaction joint tests
capture program drop inttests
program define inttests

test `1' `1'1 `1'2 `1'3 `1'4 `1'5 `1'6 `1'7 `1'8 `1'9 `1'10 `1'11 `1'12 `2' `2'1 `2'2 `2'3 `2'4 `2'5 `2'6 `2'7 `2'8 `2'9 `2'10 `2'11 `2'12 
matrix joint[1,j] = r(F)
matrix joint[2,j] = r(p)
replace j=j+1

end

***REGRESSIONS***

drop dintsdum1lpse mdum1 mdum2 intsdum1monthdum*

global int dlpse4naics* dlminwage* intsdum*monthdum* mdum* dintsdum*lpse4naics

global pol govparty_c

*Amount of credit
reg dll daet* dacf* dar* dans* recdaet* recdacf* recdar* recdans* $int $pol, vce(cluster state)
matrix coeff = e(b)
matrix covar = e(V)

linearcombos dar
linearcombos recdar
intcombos dar recdar

jointtests dar
jointtests recdar
inttests dar recdar

*Recapture provisions
reg dll drecp* dnrecp* recdrecp* recdnrecp* $int $pol, vce(cluster state)
matrix coeff = e(b)
matrix covar = e(V)

linearcombos drecp
linearcombos recdrecp
intcombos drecp recdrecp

jointtests drecp
jointtests recdrecp
inttests drecp recdrecp

***RESULTS***

matrix list linco
matrix lincot=linco'
matrix list joint
matrix jointt=joint'

putexcel set Table7, sheet(Results) modify
putexcel B2 = matrix(lincot)

putexcel set Table7, sheet(Jointtests) modify
putexcel B2 = matrix(jointt)
